unit BudgetCatADT;

interface
  type
    BudgetCat = (Entertainment, Food, Clothing, Rent, Tuition, Insurance,
                 Miscellaneous, Done);

  procedure ReadBudgetCat (var Category : BudgetCat);
  { Gets the name of the category from standard input.
    Pre : None.
    Post: Category is a value from BudgetCat.  If there is no match between
          the category name, input as a string, and the definition of
          BudgetCat, then Sentinel in BudgetCat is returned. }

  procedure WriteBudgetCat (Category : BudgetCat);
  { Prints the name of the category to standard output.
    Pre : Category is defined.
    Post: The category is written to standard output as a string. }

implementation
  const
    { This should correspond to the definition of BudgetCat. }
    Categories : array [BudgetCat] of String =
      ('Entertainment', 'Food', 'Clothing',
       'Rent', 'Tuition', 'Insurance',
       'Miscellaneous', 'Done');

  function UpString (StringText : String) : String;
  { Converts a string to uppercase.
    Pre : StringText is defined.
    Post: StringText is in uppercase. }

  var
    Index : Byte;

  begin {UpString}
    for Index := 1 to Length (StringText) do
      StringText [Index] := UpCase (StringText [Index]);
    UpString := StringText
  end; {UpString}

  procedure ReadBudgetCat (var Category : BudgetCat);
  { Gets the name of the category from standard input. }

  var
    InCategory : String;
    CategoryIndex : BudgetCat;
    CategoryFound : Boolean;

  begin {ReadBudgetCat}
    Write ('  ⥣ਨ >');
    ReadLn (InCategory);

    CategoryIndex := Entertainment;
    CategoryFound := False;
    while not CategoryFound and (CategoryIndex <= Done) do
      if UpString (InCategory) = UpString (Categories [CategoryIndex]) then
        CategoryFound := True
      else
        Inc (CategoryIndex);
    if CategoryFound then
      Category := CategoryIndex
    else
      Category := Done
  end; {ReadBudgetCat}

  procedure WriteBudgetCat (Category : BudgetCat);
  { Prints the name of the category to standard output. }

  begin {WriteBudgetCat}
    Write (Categories [Category])
  end; {WriteBudgetCat}

end. {BudgetCatADT}